@@ -141,7 +141,7 @@ class Artifacts:
             assert_that(name).is_not_none()
             # TODO: local_path?
             local_path = os.path.join(".", data.get_path(name))
-            digest, size = data.file_dump(local_path)
+            digest, size = data.file_dump(local_path, name)
             self.entry_list.append(
                 ArtifactEntry(path=data.get_path(name), local_path=local_path, size=size, digest=digest, status="ADD",
                               lfs_yn="", repo_tag="", type="TABLE", metadata=data.to_json(name), key=name))
@@ -153,11 +153,18 @@ class Artifacts:
             self.entry_list.append(
                 ArtifactEntry(path=data.get_path(name), local_path=local_path, size=size, digest=digest, status="ADD",
                               lfs_yn="", repo_tag="", type="IMAGE", metadata=data.to_json(name), key=name))
+
+            json_file_path = os.path.join(".", data.get_path(name))
+            json_digest, json_size = data.file_dump(json_file_path, name)
+            self.entry_list.append(
+                ArtifactEntry(path=data.get_path_json(name), local_path=json_file_path, size=size, digest=json_digest, status="ADD",
+                              lfs_yn="", repo_tag="", type="IMAGE", metadata=data.to_json(name), key=name))
+
         elif isinstance(data, Chart):
             assert_that(name).is_not_none()
             # TODO: local_path?
             local_path = os.path.join(".", data.get_path(name))
-            digest, size = data.file_dump(local_path)
+            digest, size = data.file_dump(local_path, name)
             self.entry_list.append(
                 ArtifactEntry(path=data.get_path(name), local_path=local_path, size=size, digest=digest, status="ADD",
                               lfs_yn="", repo_tag="", type="CHART", metadata=data.to_json(name), key=name))
@@ -173,6 +180,13 @@ class Artifacts:
                                       status="ADD",
                                       lfs_yn="", repo_tag="", type="IMAGE", metadata=n.to_json(key_name=name, is_list=True, index=index), key=name))
 
+                    json_file_path = os.path.join(".", n.get_path(name))
+                    json_digest, json_size = n.file_dump(json_file_path, name)
+                    self.entry_list.append(
+                        ArtifactEntry(path=n.get_path_json(name), local_path=json_file_path, size=size,
+                                      digest=json_digest, status="ADD",
+                                      lfs_yn="", repo_tag="", type="IMAGE", metadata=n.to_json(name), key=name))
+
 
     def __add_file(self, data: Union[str], name: str = None, depth: int = 0) -> None:
         # data에 str가 들어오면 file 인지, dir 인지 reference url(http:// or s3:// ..) 인지 체크
